summaryrefslogtreecommitdiff
path: root/dichroism/src/main.rs
diff options
context:
space:
mode:
Diffstat (limited to 'dichroism/src/main.rs')
-rw-r--r--dichroism/src/main.rs17
1 files changed, 14 insertions, 3 deletions
diff --git a/dichroism/src/main.rs b/dichroism/src/main.rs
index 68b7091..6c76f0a 100644
--- a/dichroism/src/main.rs
+++ b/dichroism/src/main.rs
@@ -3,7 +3,8 @@ extern crate serde;
#[macro_use]
extern crate diesel;
-use actix_web::{App, HttpServer};
+use actix_cors::Cors;
+use actix_web::{middleware::Logger, App, HttpServer};
use config::CONFIG_INSTANCE as CONFIG;
use diesel::prelude::SqliteConnection;
use diesel::r2d2::ConnectionManager;
@@ -25,18 +26,28 @@ mod types;
#[actix_web::main]
async fn main() -> Result<()> {
- // Initialize DB connection pool.
+ // Init logging
+ std::env::set_var("RUST_LOG", "actix_web=info");
+ env_logger::init();
+
+ // Init DB connection pool
let manager = ConnectionManager::<SqliteConnection>::new(&CONFIG.db_url);
let pool = Pool::builder().build(manager)?;
// Initialize application server.
let mut server = HttpServer::new(move || {
+ // Init CORS policy
+ let cors = Cors::permissive();
+
App::new()
.data(pool.clone())
+ .wrap(cors)
+ .wrap(Logger::default())
.service(handlers::hello)
.service(handlers::get_products)
.service(handlers::patch_product)
.service(handlers::post_product)
+ .service(handlers::post_photo)
});
// If using listenfd, bind to it instead of the configured address to allow for cargo watch
@@ -25,18 +26,28 @@ mod types;
let manager = ConnectionManager::<SqliteConnection>::new(&CONFIG.db_url);
let pool = Pool::builder().build(manager)?;
- // Initialize application server.
+ // Init application server
let mut server = HttpServer::new(move || {